import { MapData } from "@mt/components";

import { Route, Station } from "@mt/common-types";
import { useEffect, useState } from "react";
import { mapRouteFromApi } from "../mappers/mapRouteFromApi";
import { useOne, useMany } from "@refinedev/core";
import { axiosInstance } from "../../../../providers/data";

const fetchStations = async (
  routeId: string,
  setStations: (stations: any[]) => void,
  setSights: (sights: any[]) => void
) => {
  const stations = (await axiosInstance.get(`/route/${routeId}/station`)).data;
  const sights = (await axiosInstance.get(`/route/${routeId}/sight`)).data;
  setStations(stations);
  setSights(sights);

  const stationsPath = stations.map((station: any) => [
    station.latitude,
    station.longitude,
  ]);
  const sightsPath = sights.map((sight: any) => [
    sight.latitude,
    sight.longitude,
  ]);

  console.log(stationsPath, sightsPath);
};

export const useGetRouteData = (routeId: string) => {
  const [mappedData, setMappedData] = useState<MapData>(null);

  const {
    data: routeData,
    isSuccess,
    isError,
    isLoading,
  } = useOne<Route>({
    resource: "route",
    id: routeId,
  });

  const [stations, setStations] = useState<any[]>([]);
  const [sights, setSights] = useState<any[]>([]);

  useEffect(() => {
    fetchStations(routeId, setStations, setSights);
  }, [routeData]);

  // useEffect(() => {
  //   if (!routeData) {
  //     return;
  //   }

  //   // const data = mapRouteFromApi(routeData, []);

  //   setMappedData(data);
  // }, [routeData]);

  return { routeData, mappedData, isLoading, isError };
};
